@@ -1,7 +1,6 @@
 """Module responsible for storing and handling nbqa configuration."""
 
 import collections
-from pathlib import Path
 from shlex import split
 from textwrap import dedent
 from typing import Any, Callable, ClassVar, Dict, Mapping, Optional, Sequence, Union
@@ -19,8 +18,6 @@ class _ConfigSections(
         "_ConfigSections",
         (
             "ADDOPTS",
-            "CONFIG",
-            "IGNORE_CELLS",
             "PROCESS_CELLS",
             "MUTATE",
             "DIFF",
@@ -36,8 +33,6 @@ class _ConfigSections(
     def __new__(  # pylint: disable=R0913
         cls,
         ADDOPTS: str = "addopts",
-        CONFIG: str = "config",
-        IGNORE_CELLS: str = "ignore_cells",
         PROCESS_CELLS: str = "process_cells",
         MUTATE: str = "mutate",
         DIFF: str = "diff",
@@ -48,8 +43,6 @@ class _ConfigSections(
         return super().__new__(
             cls,
             ADDOPTS,
-            CONFIG,
-            IGNORE_CELLS,
             PROCESS_CELLS,
             MUTATE,
             DIFF,
@@ -74,10 +67,6 @@ class Configs:
     ----------
     nbqa_mutate
         Whether to allow nbqa to modify notebooks.
-    nbqa_config
-        Configuration of the third party tool.
-    nbqa_ignore_cells
-        Deprecated.
     nbqa_process_cells
         Process code within cells with these cell magics.
     nbqa_addopts
@@ -92,10 +81,6 @@ class Configs:
     CONFIG_SECTION_PARSERS[CONFIG_SECTIONS.ADDOPTS] = (
         lambda arg: split(arg) if isinstance(arg, str) else arg
     )
-    CONFIG_SECTION_PARSERS[CONFIG_SECTIONS.CONFIG] = str
-    CONFIG_SECTION_PARSERS[CONFIG_SECTIONS.IGNORE_CELLS] = (
-        lambda arg: arg.split(",") if isinstance(arg, str) else arg
-    )
     CONFIG_SECTION_PARSERS[CONFIG_SECTIONS.PROCESS_CELLS] = (
         lambda arg: arg.split(",") if isinstance(arg, str) else arg
     )
@@ -105,8 +90,6 @@ class Configs:
     CONFIG_SECTION_PARSERS[CONFIG_SECTIONS.EXCLUDE] = str
 
     _mutate: bool = False
-    _config: Optional[str] = None
-    _ignore_cells: Sequence[str] = []
     _process_cells: Sequence[str] = []
     _addopts: Sequence[str] = []
     _diff: bool = False
@@ -137,21 +120,11 @@ class Configs:
         """Show diff instead of replacing notebook code."""
         return self._diff
 
-    @property
-    def nbqa_config(self) -> Optional[str]:
-        """Return the configuration of the third party tool."""
-        return self._config
-
     @property
     def nbqa_addopts(self) -> Sequence[str]:
         """Additional options to be passed to the third party command to run."""
         return self._addopts
 
-    @property
-    def nbqa_ignore_cells(self) -> Sequence[str]:
-        """Don't use, deprecated."""
-        return self._ignore_cells
-
     @property
     def nbqa_process_cells(self) -> Sequence[str]:
         """Additional cells which nbqa should process."""
@@ -181,10 +154,6 @@ class Configs:
         config.set_config(
             CONFIG_SECTIONS.ADDOPTS, [*self._addopts, *other.nbqa_addopts]
         )
-        config.set_config(CONFIG_SECTIONS.CONFIG, self._config or other.nbqa_config)
-        config.set_config(
-            CONFIG_SECTIONS.IGNORE_CELLS, self._ignore_cells or other.nbqa_ignore_cells
-        )
         config.set_config(
             CONFIG_SECTIONS.PROCESS_CELLS,
             self._process_cells or other.nbqa_process_cells,
@@ -208,8 +177,6 @@ class Configs:
         config: Configs = Configs()
 
         config.set_config(CONFIG_SECTIONS.ADDOPTS, cli_args.nbqa_addopts)
-        config.set_config(CONFIG_SECTIONS.CONFIG, cli_args.nbqa_config)
-        config.set_config(CONFIG_SECTIONS.IGNORE_CELLS, cli_args.nbqa_ignore_cells)
         config.set_config(CONFIG_SECTIONS.PROCESS_CELLS, cli_args.nbqa_process_cells)
         config.set_config(CONFIG_SECTIONS.MUTATE, cli_args.nbqa_mutate)
         config.set_config(CONFIG_SECTIONS.DIFF, cli_args.nbqa_diff)
@@ -225,9 +192,6 @@ class Configs:
         defaults.set_config(
             CONFIG_SECTIONS.ADDOPTS, DEFAULT_CONFIG["addopts"].get(command)
         )
-        defaults.set_config(
-            CONFIG_SECTIONS.CONFIG, DEFAULT_CONFIG["config"].get(command)
-        )
         defaults.set_config(
             CONFIG_SECTIONS.PROCESS_CELLS, DEFAULT_CONFIG["process_cells"].get(command)
         )
@@ -250,8 +214,6 @@ class Configs:
         ------
         ValueError
             If both --nbqa-diff and --nbqa-mutate are used together.
-        FileNotFoundError
-            If config file provided does not exist.
         """
         if self._diff and self._mutate:
             raise ValueError(
@@ -263,10 +225,3 @@ class Configs:
                     """
                 )
             )
-        if self.nbqa_config and not Path(self.nbqa_config).exists():
-            raise FileNotFoundError(f"{self.nbqa_config} not found.")
-        if self.nbqa_ignore_cells:
-            raise ValueError(
-                "--nbqa-ignore-cells is deprecated since version 0.6.0, "
-                "most cell magics are now excluded by default."
-            )
